@@ -545,6 +545,7 @@ typedef intptr_t (*Scheme_Secondary_Hash_Proc)(Scheme_Object *obj, void *cycle_d
 
 #define SCHEME_THREADP(obj)   SAME_TYPE(SCHEME_TYPE(obj), scheme_thread_type)
 #define SCHEME_CUSTODIANP(obj)   SAME_TYPE(SCHEME_TYPE(obj), scheme_custodian_type)
+#define SCHEME_PLUMBERP(obj)   SAME_TYPE(SCHEME_TYPE(obj), scheme_plumber_type)
 #define SCHEME_SEMAP(obj)   SAME_TYPE(SCHEME_TYPE(obj), scheme_sema_type)
 #define SCHEME_CHANNELP(obj)   SAME_TYPE(SCHEME_TYPE(obj), scheme_channel_type)
 #define SCHEME_CHANNEL_PUTP(obj)   SAME_TYPE(SCHEME_TYPE(obj), scheme_channel_put_type)
@@ -956,7 +957,12 @@ typedef struct Scheme_Env Scheme_Env;
 /*========================================================================*/
 
 #ifdef USE_MZ_SETJMP
+# if defined(_WIN64)
+#  define USE_MZ_SETJMP_INDIRECT
+typedef intptr_t mz_pre_jmp_buf[31];
+# else
 typedef intptr_t mz_pre_jmp_buf[8];
+# endif
 #else
 # define mz_pre_jmp_buf jmp_buf
 #endif
@@ -1007,6 +1013,23 @@ typedef struct Scheme_Continuation_Jump_State {
   char is_kill, is_escape, skip_dws;
 } Scheme_Continuation_Jump_State;
 
+#ifdef USE_MZ_SETJMP_INDIRECT
+/* Needed to avoid a direct reference to scheme_mz_setjmp,
+   which might be implemented in assembly and incompatible
+   with delayloading: */
+typedef int (*Scheme_Setjmp_Proc)(mz_pre_jmp_buf);
+# ifndef MZ_XFORM
+#  define scheme_call_mz_setjmp(s) ((scheme_get_mz_setjmp())(s))
+# else
+#  define scheme_call_mz_setjmp(s) scheme_mz_setjmp_post_xform(s)
+# endif
+#else
+# ifdef USE_MZ_SETJMP
+#  define scheme_call_mz_setjmp(s) scheme_mz_setjmp(s)
+# endif
+typedef int (*Scheme_Setjmp_Proc)(void*);
+#endif
+
 /* A mark position is in odd number, so that it can be
    viewed as a pointer (i.e., a fixnum): */
 #define MZ_MARK_POS_TYPE intptr_t
@@ -1044,6 +1067,7 @@ typedef struct Scheme_Custodian *Scheme_Custodian_Reference;
 typedef struct Scheme_Custodian Scheme_Custodian;
 typedef Scheme_Bucket_Table Scheme_Thread_Cell_Table;
 typedef struct Scheme_Config Scheme_Config;
+typedef struct Scheme_Plumber Scheme_Plumber;
 
 typedef int (*Scheme_Ready_Fun)(Scheme_Object *o);
 typedef void (*Scheme_Needs_Wakeup_Fun)(Scheme_Object *, void *);
@@ -1357,6 +1381,7 @@ enum {
   MZCONFIG_CUSTODIAN,
   MZCONFIG_INSPECTOR,
   MZCONFIG_CODE_INSPECTOR,
+  MZCONFIG_PLUMBER,
 
   MZCONFIG_USE_COMPILED_KIND,
   MZCONFIG_USE_COMPILED_ROOTS,
@@ -1683,20 +1708,20 @@ MZ_EXTERN Scheme_Object *scheme_eval_waiting;
 #ifndef USE_MZ_SETJMP
 # ifdef USE_UNDERSCORE_SETJMP
 #  define scheme_mz_longjmp(b, v) _longjmp(b, v)
-#  define scheme_mz_setjmp(b) _setjmp(b)
+#  define scheme_call_mz_setjmp(b) _setjmp(b)
 # else
 #  define scheme_mz_longjmp(b, v) longjmp(b, v)
-#  define scheme_mz_setjmp(b) setjmp(b)
+#  define scheme_call_mz_setjmp(b) setjmp(b)
 # endif
 #endif
 
 #ifdef MZ_USE_JIT
 MZ_EXTERN void scheme_jit_longjmp(mz_jit_jmp_buf b, int v);
 MZ_EXTERN void scheme_jit_setjmp_prepare(mz_jit_jmp_buf b);
-# define scheme_jit_setjmp(b) (scheme_jit_setjmp_prepare(b), scheme_mz_setjmp((b)->jb))
+# define scheme_jit_setjmp(b) (scheme_jit_setjmp_prepare(b), scheme_call_mz_setjmp((b)->jb))
 #else
 # define scheme_jit_longjmp(b, v) scheme_mz_longjmp(b, v) 
-# define scheme_jit_setjmp(b) scheme_mz_setjmp(b) 
+# define scheme_jit_setjmp(b) scheme_call_mz_setjmp(b)
 #endif
 
 #ifdef MZ_PRECISE_GC
